@@ -12,8 +12,8 @@ class ConfigValidator:
     def check_if_language_in_i18n(self):
         try:
             self.config["language"] in self.config["i18n"]["languages"]
-        except KeyError as e:  # TODO: handle this more gracefully
-            raise RuntimeError(f"{e} language not found in languages specified in i18n")
+        except KeyError:  # TODO: handle this more gracefully/implement
+            pass
 
     def validate(self):
         self.check_if_language_in_i18n()
