@@ -1,4 +1,4 @@
-TRANSLATIONS = {
+TRANSLATIONS: dict = {
     "read-more": {"en": "Read More", "pl": "Czytaj dalej"},
     "copy": {"en": "Powered by XD philosophy and ", "pl": "Całość zasilana przez filozofię XD oraz "},
-}
+}  # TODO: Load this from a file
